import pandas as pd
import numpy as np
from tools import file_reader, explainer
import paths as pt
from pathlib import Path

def main():
    model = file_reader.read_joblib(pt.COMPLETE_XGB_DIR,
                                    'complete_xgboost.joblib')
    
    converters = {str(i)+'Ats':str for i in range(1, 10+1)}
    df = file_reader.read_csv(pt.TESTS_FILES_DIR,
                              'test_citizens.csv',
                              converters=converters)
    
    for i in range(1, 10+1):
        path = Path.joinpath(pt.PROCESSED_DATA_DIR, 'embeddings')
        embedding = file_reader.read_embedding(path, f'complete_{i}Ats.csv')
        column = f'{i}Ats'
        df[column] = df[column].replace(to_replace=embedding)
        df[column] = pd.to_numeric(df[column])
    
    test_citizen = pd.DataFrame(df.iloc[0]).T
    print(test_citizen)
    
    prediction = model.predict(test_citizen)
    probability = model.predict_proba(test_citizen).max()
    _, shap_values = explainer.get_shap_tree_explainer(model, X_test=test_citizen)
    shap_values_flat = [round(float(val), 3) for val in shap_values[0]]
    shap_values_dict = dict(zip(test_citizen.columns, shap_values_flat))
    
    print(f"Predicted {int(prediction[0])} with probability {round(float(probability), 3)*100}%")
    
    for item, amount in shap_values_dict.items():
        print("{} ({})".format(item, amount))
        
if __name__ == "__main__":
    main()