#!/usr/bin/env python

import numpy as np
import pandas as pd
import paths as pt
import yaml
from typing import List
from kmodes import kmodes
from pathlib import Path
from tools import file_reader, file_writer, preprocessor

def main():
    df = file_reader.read_csv(pt.INTERIM_DATA_DIR, 'screenings.csv',
                              converters={'CitizenId': str})
    df = preprocessor.split_cat_columns(df, col_to_split='Ats', tag='Ats', resolution=10)

    cols_ats = [str(i)+'Ats' for i in range(1, 11)]
    header_list = ['CitizenId'] + cols_ats
    df = df[header_list]
    
    model = kmodes.KModes(init='Huang', n_clusters=20, n_init=15, n_jobs=-1)
    model.fit(df.iloc[:, 1:].astype(str))
    
    predictions = model.predict(df.iloc[:, 1:].to_numpy())
    clusters = pd.Series(predictions, name="Cluster")

    ats_sequence = df[cols_ats].apply(lambda x: ','.join(x.dropna().astype(str)), axis=1)
    clusters = pd.DataFrame({
        'CitizenId': df['CitizenId'],
        'Cluster': clusters,
        'Ats': ats_sequence
    })
    
    cluster_centroids = pd.DataFrame(dict([i for i in zip(range(0, len(model.cluster_centroids_)),
                                             model.cluster_centroids_)]))
    
    file_writer.write_joblib(model, pt.CLUSTERS_DIR, 'km.joblib')
    file_writer.write_csv(cluster_centroids, pt.INTERIM_DATA_DIR, f'cluster_centroids.csv')
    file_writer.write_csv(clusters, pt.INTERIM_DATA_DIR, 'cl.csv')

if __name__ == '__main__':
    main()
