#!/usr/bin/env python
import paths as pt
from tools import file_reader, file_writer
from tools import preprocessor
from utility import embedder
import pandas as pd
import numpy as np
from pathlib import Path
import yaml

def main():
    for target_name in ["Complete", "Compliance", "Fall", "Risk"]:
        # Load settings for target
        with open(Path.joinpath(pt.CONFIGS_DIR,
                                f'{target_name.lower()}_emb.yaml'), 'r') as stream:
            settings = yaml.safe_load(stream)
            
        if target_name in ["Complete", "Compliance", "Fall"]:
            ats = {str(i)+'Ats':str for i in range(1, settings['ats_resolution']+1)}
            df = file_reader.read_csv(pt.PROCESSED_DATA_DIR,
                                    f'{target_name.lower()}.csv',
                                    converters=ats)
        else:
            ex = {str(i)+'Ex':str for i in range(1, settings['ex_resolution']+1)}
            ats = {str(i)+'Ats':str for i in range(1, settings['ats_resolution']+1)}
            converters = {**ex, **ats}
            df = file_reader.read_csv(pt.PROCESSED_DATA_DIR,
                                    f'{target_name.lower()}.csv',
                                    converters=converters)
            
        # One-hot encode targets
        if target_name in ["Complete", "Compliance", "Fall"]:
            ats_cols = [str(i)+'Ats' for i in range(1, settings['ats_resolution']+1)]
            df_enc = preprocessor.one_hot_encode(df, ats_cols)
            df = pd.concat([df.drop(ats_cols + [target_name], axis=1),
                            df_enc, df[[target_name]]], axis=1)
        else:
            ex_cols = [str(i)+'Ex' for i in range(1, settings['ex_resolution']+1)]
            ats_cols = [str(i)+'Ats' for i in range(1, settings['ats_resolution']+1)]
            total_cols = ex_cols + ats_cols
            df_enc = preprocessor.one_hot_encode(df, total_cols)
            df = pd.concat([df.drop(total_cols + [target_name], axis=1),
                            df_enc, df[[target_name]]], axis=1)
            
        # Save dataframe
        file_writer.write_csv(df, pt.PROCESSED_DATA_DIR, f'{target_name.lower()}_ohe.csv')
    
if __name__ == "__main__":
    main()