import streamlit as st
import pandas as pd
import numpy as np
import pickle
from pathlib import Path
import os

def load_model():
    dir_path = os.path.dirname(os.path.realpath(__file__))
    with open(f'{dir_path}/models/completes_ats_model.pkl', 'rb') as f:
        model = pickle.load(f)
    return model

def main():
    data_dict = {
    'Jens Jensen': pd.DataFrame({
            'Gender': [1],
            'Age': [57],
            'Cluster': [0],
            'NumberAtsMean': [27],
            'HadRollator': [True],
            'HadShowerStool': [True],
            'HadRaisedToiletSeat': [False],
            'HadEmergencySystem': [False],
            'HadSeatCushion': [False],
            'HadWheelchair': [False],
            'HadBedWithEngine': [False]
        }),
    'Hans Hansen': pd.DataFrame({
            'Gender': [1],
            'Age': [79],
            'Cluster': [10],
            'NumberAtsMean': [5],
            'HadRollator': [False],
            'HadShowerStool': [True],
            'HadRaisedToiletSeat': [True],
            'HadEmergencySystem': [False],
            'HadSeatCushion': [False],
            'HadWheelchair': [False],
            'HadBedWithEngine': [True]
        }),
    'Tom Tomsen': pd.DataFrame({
            'Gender': [1],
            'Age': [90],
            'Cluster': [48],
            'NumberAtsMean': [15],
            'HadRollator': [False],
            'HadShowerStool': [False],
            'HadRaisedToiletSeat': [False],
            'HadEmergencySystem': [False],
            'HadSeatCushion': [False],
            'HadWheelchair': [False],
            'HadBedWithEngine': [False]
        })
    }

    st.title('Hvem vil gennemføre sin træning?')
    citizen = st.selectbox(
        'Vælg en borger fra listen',
        ('Jens Jensen', 'Hans Hansen', 'Tom Tomsen')
    )
    
    st.write('Du har valgt:', citizen)

    if st.checkbox('Vis data for borger', value=True):
        st.subheader(f'Oplysninger om hjælpemidler for {citizen}')
        data = np.transpose(data_dict[citizen])
        data = data.rename(columns={0:'Oplysninger'})
        st.dataframe(data)

    st.subheader(f'Lav en forudsigelse for borger {citizen}')
    model = load_model()
    oob_sample = data_dict[citizen]
    if st.button('Lav forudsigelse'):
        pred = model.predict(oob_sample)
        pred_proba = model.predict_proba(oob_sample)
        result = 'vil gennemføre' if pred[0] == 1 else 'ikke vil gennemføre'
        st.write(f'Vi kan forudsige, at {citizen} {result}')
        st.write(f'Fordeling af sandsynlighed: {pred_proba[0]}')

if __name__== '__main__':
   main()
   